@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,9 +68,10 @@ import javax.mail.Folder;
 import javax.mail.MessagingException;
 import javax.mail.internet.idn.IDNA;
 import com.openexchange.exception.OXException;
-import com.openexchange.java.StringAllocator;
 import com.openexchange.java.Strings;
+import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.mime.MimeMailException;
+import com.openexchange.mail.mime.MimeMailExceptionCode;
 import com.openexchange.mail.mime.MimeSessionPropertyNames;
 import com.openexchange.pop3.POP3ExceptionCode;
 import com.openexchange.pop3.POP3Provider;
@@ -231,7 +232,7 @@ public final class POP3StoreConnector {
      * @return A connected instance of {@link POP3Store}
      * @throws OXException If establishing a connected instance of {@link POP3Store} fails
      */
-    public static POP3StoreResult getPOP3Store(final POP3Config pop3Config, final Properties pop3Properties, final boolean monitorFailedAuthentication, final Session session, final boolean errorOnMissingUIDL) throws OXException {
+    public static POP3StoreResult getPOP3Store(final POP3Config pop3Config, final Properties pop3Properties, final boolean monitorFailedAuthentication, final Session session, final boolean errorOnMissingUIDL, final boolean forceSecure) throws OXException {
         try {
             final boolean tmpDownEnabled = (POP3Properties.getInstance().getPOP3TemporaryDown() > 0);
             if (tmpDownEnabled) {
@@ -326,6 +327,9 @@ public final class POP3StoreConnector {
                 /*
                  * Enables the use of the STARTTLS command (if supported by the server) to switch the connection to a TLS-protected connection.
                  */
+                if (forceSecure && staticCapabilities.indexOf("STLS") < 0) {
+                    throw MailExceptionCode.NON_SECURE_DENIED.create(pop3Config.getServer());
+                }
                 pop3Props.put("mail.pop3.starttls.enable", "true");
                 /*
                  * Specify the javax.net.ssl.SSLSocketFactory class, this class will be used to create POP3 SSL sockets if TLS handshake says
@@ -379,7 +383,7 @@ public final class POP3StoreConnector {
                 // Fetch capabilities again
                 final Map<String, String> caps = pop3Store.reinitCapabilities();
                 if (!caps.isEmpty()) {
-                    final StringAllocator sb = new StringAllocator(128);
+                    final StringBuilder sb = new StringBuilder(128);
                     for (final String cap : caps.keySet()) {
                         sb.append(cap).append('\n');
                     }
@@ -397,7 +401,7 @@ public final class POP3StoreConnector {
                 // Fetch capabilities again
                 final Map<String, String> caps = pop3Store.reinitCapabilities();
                 if (!caps.isEmpty()) {
-                    final StringAllocator sb = new StringAllocator(128);
+                    final StringBuilder sb = new StringBuilder(128);
                     for (final String cap : caps.keySet()) {
                         sb.append(cap).append('\n');
                     }
@@ -414,16 +418,22 @@ public final class POP3StoreConnector {
                 }
                 throw e;
             } catch (final MessagingException e) {
-                /*
-                 * TODO: Re-think if exception's message should be part of condition or just checking if nested exception is an instance of
-                 * SocketTimeoutException
-                 */
-                if (tmpDownEnabled && SocketTimeoutException.class.isInstance(e.getNextException())) {
-                    /*
-                     * Remember a timed-out POP3 server on connect attempt
-                     */
-                    timedOutServers.put(new HostAndPort(server, port), Long.valueOf(System.currentTimeMillis()));
+                final Exception nested = e.getNextException();
+                if (nested != null) {
+                    if (nested instanceof IOException) {
+                        throw MimeMailExceptionCode.CONNECT_ERROR.create(e, pop3Config.getServer(), pop3Config.getLogin());
+                    } else if (tmpDownEnabled && SocketTimeoutException.class.isInstance(e.getNextException())) {
+                        /*
+                         * TODO: Re-think if exception's message should be part of condition or just checking if nested exception is an instance of
+                         * SocketTimeoutException
+                         */
+                        /*
+                         * Remember a timed-out POP3 server on connect attempt
+                         */
+                        timedOutServers.put(new HostAndPort(server, port), Long.valueOf(System.currentTimeMillis()));
+                    }
                 }
+
                 throw e;
             }
             /*
