@@ -147,6 +147,17 @@ public class MailAccountPOP3MessageStorage implements ISimplifiedThreadStructure
         throw MailExceptionCode.UNSUPPORTED_OPERATION.create();
     }
 
+    @Override
+    public Message getMimeMessage(String fullName, String id, boolean markSeen) throws OXException {
+        if (delegatee instanceof IMailMessageStorageMimeSupport) {
+            final IMailMessageStorageMimeSupport streamSupport = (IMailMessageStorageMimeSupport) delegatee;
+            if (streamSupport.isMimeSupported()) {
+                return streamSupport.getMimeMessage(fullName, id, markSeen);
+            }
+        }
+        throw MailExceptionCode.UNSUPPORTED_OPERATION.create();
+    }
+
     @Override
     public String[] appendMessages(final String destFolder, final MailMessage[] msgs) throws OXException {
         /*
@@ -441,6 +452,11 @@ public class MailAccountPOP3MessageStorage implements ISimplifiedThreadStructure
         delegatee.updateMessageColorLabel(getRealFullname(folder), mailIds, colorLabel);
     }
 
+    @Override
+    public void updateMessageUserFlags(final String folder, final String[] mailIds, final String[] flags, final boolean set) throws OXException {
+        delegatee.updateMessageUserFlags(folder, mailIds, flags, set);
+    }
+
     @Override
     public void updateMessageFlags(final String folder, final String[] mailIds, final int flags, final boolean set) throws OXException {
         delegatee.updateMessageFlags(getRealFullname(folder), mailIds, flags, set);
